@@ -18,10 +18,10 @@
 # along with pytest-postgresql. If not, see <http://www.gnu.org/licenses/>.
 """Main module for pytest-postgresql."""
 try:
-    import psycopg2cffi.compat  # pylint:disable=import-error
+    import psycopg2cffi.compat
 except ImportError:
     pass
 else:
     psycopg2cffi.compat.register()
 
-__version__ = "3.1.1"
+__version__ = "3.1.2"
