@@ -42,7 +42,7 @@ def postgresql(
     :param load: SQL, function or function import paths to automatically load
                  into our test database
     :param isolation_level: optional postgresql isolation level
-                            defaults to ISOLATION_LEVEL_AUTOCOMMIT
+                            defaults to server's default
     :returns: function which makes a connection to postgresql
     """
 
@@ -56,7 +56,6 @@ def postgresql(
         """
         config = get_config(request)
         check_for_psycopg2()
-        pg_isolation_level = isolation_level or psycopg2.extensions.ISOLATION_LEVEL_AUTOCOMMIT
         proc_fixture: Union[PostgreSQLExecutor, NoopExecutor] = request.getfixturevalue(
             process_fixture_name
         )
@@ -70,7 +69,7 @@ def postgresql(
         pg_load = load or config["load"]  # TODO: only a fixture param should be left here.
 
         with DatabaseJanitor(
-            pg_user, pg_host, pg_port, pg_db, proc_fixture.version, pg_password, pg_isolation_level
+            pg_user, pg_host, pg_port, pg_db, proc_fixture.version, pg_password, isolation_level
         ) as janitor:
             db_connection: connection = psycopg2.connect(
                 dbname=pg_db,
